@@ -67,8 +67,6 @@ app_init (GtkApplication *app)
   gtk_window_set_application (window, app);
   gtk_widget_show (GTK_WIDGET (window));
 
-  vinagre_utils_handle_debug ();
-
 #ifdef VINAGRE_HAVE_TELEPATHY_GLIB
   vinagre_tubes_manager = vinagre_tubes_manager_new (VINAGRE_WINDOW (window));
 #endif
@@ -125,17 +123,17 @@ int main (int argc, char **argv) {
   GHashTableIter iter;
   int res;
 
-  g_set_prgname ("vinagre");
-  g_type_init ();
-  g_set_application_name (_("Remote Desktop Viewer"));
-  optionstate.new_window = FALSE;
-
   /* i18n */
   setlocale (LC_ALL, "");
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+  g_set_prgname (PACKAGE_TARNAME);
+  g_type_init ();
+  g_set_application_name (_("Remote Desktop Viewer"));
+  optionstate.new_window = FALSE;
+
   /* Setup command line options */
   context = g_option_context_new (_("- Remote Desktop Viewer"));
   g_option_context_add_main_entries (context, all_options, GETTEXT_PACKAGE);
